const fs = require('fs');
const path = require('path');
const { encrypt } = require('./encrypt');
const { decrypt } = require('./decrypt');

const defaultKey = 'your-32-character-key-here'; // Anahtar 32 karakter uzunluğunda olmalı

function encryptEnvContent(content, key = defaultKey) {
  return content.split('\n')
    .map(line => {
      if (line.trim() && !line.startsWith('#')) {
        const [k, v] = line.split('=');
        return `${k}=${encrypt(v.trim(), key)}`;
      }
      return line;
    })
    .join('\n');
}

function decryptEnvContent(content, key = defaultKey) {
  return content.split('\n')
    .map(line => {
      if (line.trim() && !line.startsWith('#')) {
        const [k, v] = line.split('=');
        return `${k}=${decrypt(v.trim(), key)}`;
      }
      return line;
    })
    .join('\n');
}

function saveEnv(filePath, content, key = defaultKey) {
  const encryptedContent = encryptEnvContent(content, key);
  fs.writeFileSync(filePath, encryptedContent);
}

function loadEnv(filePath = '.private', key = defaultKey) {
  if (!fs.existsSync(filePath)) {
    console.error(`File not found: ${filePath}`);
    return;
  }

  const encryptedContent = fs.readFileSync(filePath, 'utf8');
  const envContent = decryptEnvContent(encryptedContent, key);

  envContent.split('\n')
    .filter(line => line && !line.startsWith('#'))
    .forEach(line => {
      const [k, v] = line.split('=');
      process.env[k.trim()] = v.trim();
    });
}

module.exports = { loadEnv, saveEnv };
